@@ -4,7 +4,7 @@ package Method::Traits;
 use strict;
 use warnings;
 
-our $VERSION   = '0.03';
+our $VERSION   = '0.04';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use Carp                   ();
@@ -186,7 +186,7 @@ sub apply_all_trait_handlers {
 
     foreach my $trait ( @$traits ) {
         my ($args, $handler) = ($trait->args, $trait->handler);
-        $handler->body->( $meta, $method_name, @$args );
+        $handler->body->( $meta, $method, @$args );
         if ( $handler->has_code_attributes('OverwritesMethod') ) {
             $method = $meta->get_method( $method_name );
             Carp::croak('Failed to find new overwriten method ('.$method_name.') in class ('.$meta->name.')')
@@ -209,7 +209,7 @@ Method::Traits - Apply traits to your methods
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -236,7 +236,9 @@ version 0.03
     use Method::Traits ':for_providers';
 
     sub Accessor : OverwritesMethod {
-        my ($meta, $method_name, $type, $slot_name) = @_;
+        my ($meta, $method, $type, $slot_name) = @_;
+
+        my $method_name = $method->name;
 
         $meta->add_method( $method_name => sub {
             die 'ro accessor' if $_[1];
@@ -302,9 +304,9 @@ provider, and if found, will call that trait.
 The traits are called immediately when the "attribute" mechanism
 is triggered. The trait callbacks receieve at least two arguments,
 the first being a L<MOP::Class> instance representing the
-subroutine's package, the next being the name of that subroutine,
-and then, if there are any arguments passed to the trait, they are
-also passed along.
+subroutine's package, the next being the L<MOP::Method> instance
+representing the subroutine itself, and then, if there are any
+arguments passed to the trait, they are also passed along.
 
 =head1 UNDER CONSTRUCTION
 
